import * as pulumi from '@pulumi/pulumi';
import * as aws from '@pulumi/aws';
import * as awsx from '@pulumi/awsx';
export declare type LanguageExtension = 'ts' | 'py' | 'go' | 'cs' | 'js' | 'swift';
export declare type Args = {
    sourceDir: string;
    sourceExt: LanguageExtension;
    sourceZip: string;
    runtime: string;
    timeout: number;
    memory: number;
    environmentVariables: {
        name: string;
        value: string;
    }[];
    domain?: {
        domain: string;
        fqd: string;
        subdomain: string;
    };
};
/**
 * Static website using Amazon S3, CloudFront, and Route53.
 */
export declare class AWSLambdaAPI extends pulumi.ComponentResource {
    readonly api: awsx.apigateway.API;
    readonly lambdas: aws.lambda.Function[];
    readonly aRecord?: aws.route53.Record;
    constructor(name: string, args: Args, opts?: pulumi.ResourceOptions);
}
export declare type Function = {
    name: string;
    module: string;
    path: string;
    route: string;
};
declare type ModuleFunction = {
    function: string;
    module: string;
    paths: {
        import: string;
        file: string;
    };
};
/**
 * Looks in ./src/modules for your modules and
 * functions. Returns their names and locations
 * as an array.
 */
export declare function getFunctionMap({ path: rootPath, ext }: {
    path: string;
    ext: LanguageExtension;
}): ModuleFunction[];
export {};
